@@ -18,7 +18,7 @@ from util import ip
 from util.cache import Cache
 from util.config import init_config, get_config
 
-__version__ = "v2.10.3@2021-10-12T06:26:53+00:00"  # CI 时会被Tag替换
+__version__ = "v2.11.1@2022-07-28T13:00:27+00:00"  # CI 时会被Tag替换
 __description__ = "automatically update DNS records to dynamic local IP [自动更新DNS记录指向本地IP]"
 __doc__ = """
 ddns[%s]
@@ -27,7 +27,7 @@ ddns[%s]
 Copyright (c) New Future (MIT License)
 """ % (__version__)
 
-environ["DDNS_VERSION"] = "v2.10.3"
+environ["DDNS_VERSION"] = "v2.11.1"
 
 if getattr(sys, 'frozen', False):
     # https://github.com/pyinstaller/pyinstaller/wiki/Recipe-OpenSSL-Certificate
@@ -93,7 +93,8 @@ def update_ip(ip_type, cache, dns, proxy_list):
     if not domains:
         return None
     if not isinstance(domains, list):
-        domains = domains.strip('; ').replace(',',';').replace(' ',';').split(';')
+        domains = domains.strip('; ').replace(
+            ',', ';').replace(' ', ';').split(';')
     index_rule = get_config('index' + ip_type, "default")  # 从配置中获取index配置
     address = get_ip(ip_type, index_rule)
     if not address:
@@ -136,7 +137,7 @@ def main():
 
     proxy = get_config('proxy') or 'DIRECT'
     proxy_list = proxy if isinstance(
-        proxy, list) else proxy.strip('; ').replace(',',';').split(';')
+        proxy, list) else proxy.strip('; ').replace(',', ';').split(';')
 
     cache = get_config('cache', True) and Cache(CACHE_FILE)
     if cache is False:
@@ -151,4 +152,8 @@ def main():
 
 
 if __name__ == '__main__':
+    if sys.version_info.major == 3 and os_name == 'nt':
+        from io import TextIOWrapper
+        sys.stdout = TextIOWrapper(sys.stdout.detach(), encoding='utf-8')
+        sys.stderr = TextIOWrapper(sys.stderr.detach(), encoding='utf-8')
     main()
